@@ -1,3 +1,18 @@
+/*
+ * robconsole.cpp
+ * 
+ * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * and Martin Trautmann (martintrautmann@gmx.de) 
+ * 
+ * This file may be distributed and/or modified under the terms of the 
+ * GNU General Public License version 2 as published by the Free Software 
+ * Foundation. 
+ * 
+ * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * 
+ */
+
 /** @file robconsole.cpp
   * Implements all console specific stuff for RoboTour.
   * E.g. ConsoleFrontend, ConsoleBotPresenter, ...<br>
@@ -65,14 +80,18 @@ void ConsoleFrontend::handleWarning(const String& message) const
 }
 
 
+void ConsoleFrontend::printVersion()
+{
+	System::println(String("Version ") + userVersion); 
+	System::println(aboutText); 
+	System::println(); 
+}
+
 void ConsoleFrontend::printHelp()
 {
-	String myVersion = version;
-#ifndef __RBI__
-	myVersion += " (No RBI support)";
-#endif
+	printVersion(); 
+
 	System::println("Usage: robotour [options] prog1 [prog2 [...]]");
-	System::println(String("Version ") + myVersion);
 	System::println();
 	System::println("Options:");
 	System::println("  -h, -help  Print this help text."); 
@@ -235,12 +254,18 @@ bool ConsoleFrontend::interpreteParamsImpl(const Array<String>& params, Array<bo
 			}
 
 			// "h"elp or "help"
-			else if((arg == "h") || (arg == "H") || !arg.compareIgnoreCase("help"))
+			else if((arg == "h") || (arg == "H") || !arg.compareIgnoreCase("help") || !arg.compareIgnoreCase("-help"))
 			{
 				printHelp();
 				return false;
 			}
 
+			else if((arg == "version") || (arg == "-version")) 
+			{
+				printVersion();
+				return false; 
+			}
+
 #ifdef __SYMBIAN32__
 			// current folder
 			else if(!arg.compareIgnoreCase("cd"))
