@@ -1,9 +1,27 @@
+/*
+ * robwxvis.cpp
+ * 
+ * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
+ * and Martin Trautmann (martintrautmann@gmx.de) 
+ * 
+ * This file may be distributed and/or modified under the terms of the 
+ * GNU General Public License version 2 as published by the Free Software 
+ * Foundation. 
+ * 
+ * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * 
+ */
+
+// Implements the main visualization frame
+
 #include <wx/wx.h>
 #include <wx/config.h>
 #include <wx/splitter.h>
 #include <wx/imaglist.h>
 #include <wx/mimetype.h>
 
+#include "robpackage.h"
 #include "robwxvis.h"
 #include "robwxutil.h"
 #include "robwxdlgs.h"
@@ -579,15 +597,17 @@ void RobVisFrame::On3DField(wxCommandEvent&)
 
 void RobVisFrame::OnAbout(wxCommandEvent&)
 {
-	wxMessageBox("RoboTour, the fast and portable RoboCom interpreter.\n"
-		"Copyright (C) 2000-2004 Florian Fischer, Martin Trautmann.", 
+	wxMessageBox(wxString("RoboTour, the fast and portable RoboCom interpreter.\n") + rt::aboutText, 
 		"About RoboTour", wxICON_INFORMATION | wxOK); 
 }
 
 void RobVisFrame::OnHelp(wxCommandEvent&)
 {
-	wxString helpIdx = Wx::Conv(lrt::File(lrt::File::getExecutableFile().getParentFile(), "help/index.html").getName()); 
-	Wx::ShowInBrowser(helpIdx); 
+	lrt::String helpFile = findHelpFile("index.html"); 
+	if(!helpFile.length()) // NOT FOUND
+		wxMessageBox("The RoboTour help was not found!", "RoboTour Help", wxICON_ERROR); 
+	else
+		Wx::ShowInBrowser(Wx::Conv(helpFile)); 
 }
 
 void RobVisFrame::OnSpeed(wxCommandEvent&)
